@@ -1,11 +1,10 @@
 package urpm::signature;
 
-# $Id: signature.pm 253617 2009-03-05 11:18:45Z tv $
 
 use strict;
 use urpm::msg;
 use urpm::media;
-use urpm::util;
+use urpm::util qw(any basename);
 
 
 =head1 NAME
@@ -123,7 +122,6 @@ sub _check {
 
 1;
 
-__END__
 
 =back
 
@@ -133,4 +131,6 @@ Copyright (C) 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
+Copyright (C) 2011-2020 Mageia
+
 =cut
