@@ -56,7 +56,8 @@ sub conflicts { $_[0]{pkg}->conflicts }
 sub obsoletes { $_[0]{pkg}->obsoletes }
 sub provides  { $_[0]{pkg}->provides }
 sub requires  { $_[0]{pkg}->requires }
-sub suggests  { $_[0]{pkg}->suggests }
+sub suggests  { $_[0]{pkg}->recommends_nosense }
+sub recommends{ $_[0]{pkg}->recommends_nosense }
 
 
 =item url($pkg)
@@ -121,4 +122,6 @@ Copyright (C) 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
+Copyright (C) 2011-2020 Mageia
+
 =cut
